@@ -7,9 +7,7 @@
 **      Date Started: Sep 2000
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -28,11 +26,6 @@
 #ifndef _TIMER_H
 #define _TIMER_H
 
-// pragma line required for Fedora 4 and wxWin 2.4.2
-#if defined(__GNUG__) && !defined(__APPLE__)
-   #pragma implementation "timer.h"
-#endif
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
