@@ -359,7 +359,7 @@ SGP::setRasterOp (int ro)
 {
 #if HAVE_WXWINDOWS
   if (m_driver.isWX()) {
-    int wxFxn = -1;
+    wxRasterOperationMode wxFxn;
     switch (ro) {
     case RO_AND:
       wxFxn = wxAND;
@@ -409,9 +409,10 @@ SGP::setRasterOp (int ro)
     case RO_XOR:
       wxFxn = wxXOR;
       break;
+    default:
+      return;
     }
-    if (wxFxn >= 0)
-      m_driver.idWX()->SetLogicalFunction (wxFxn);
+    m_driver.idWX()->SetLogicalFunction (wxFxn);
   }
 #endif
 }
