@@ -91,13 +91,13 @@ Projections::convertInterpNameToID (const char* const interpName)
 {
   int interpID = POLAR_INTERP_INVALID;
 
-  for (int i = 0; i < s_iInterpCount; i++)
+  for (int i = 0; i < s_iInterpCount; i++) {
     if (strcasecmp (interpName, s_aszInterpName[i]) == 0) {
       interpID = i;
       break;
     }
-
-    return (interpID);
+  }
+  return (interpID);
 }
 
 const char*
@@ -105,9 +105,9 @@ Projections::convertInterpIDToName (const int interpID)
 {
   static const char *interpName = "";
 
-  if (interpID >= 0 && interpID < s_iInterpCount)
+  if (interpID >= 0 && interpID < s_iInterpCount) {
     return (s_aszInterpName[interpID]);
-
+  }
   return (interpName);
 }
 
@@ -116,9 +116,9 @@ Projections::convertInterpIDToTitle (const int interpID)
 {
   static const char *interpTitle = "";
 
-  if (interpID >= 0 && interpID < s_iInterpCount)
+  if (interpID >= 0 && interpID < s_iInterpCount) {
     return (s_aszInterpTitle[interpID]);
-
+  }
   return (interpTitle);
 }
 
