@@ -7,9 +7,7 @@
 **   Date Started:  Jan 2001
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -58,7 +56,6 @@ private:
   bool m_bWireframe;
   bool m_bLighting;
   bool m_bColor;
-  bool m_bUseVertexArrays;
   bool m_bColorScaleMinSet;
   bool m_bColorScaleMaxSet;
   enum {
@@ -70,14 +67,7 @@ private:
   double m_dGraphMax;
   double m_dColorScaleMin;
   double m_dColorScaleMax;
-
-  void Draw();
-  void DrawSurface();
-  void CreateDisplayList();
-  void InitMaterials();
-  void InitGL();
-
-  Graph3dFileCanvas *CreateCanvas (wxFrame* parent);
+  wxGLContext *m_pGLContext;
 
 #if CTSIM_MDI
   wxDocMDIChildFrame* m_pFrame;
@@ -87,6 +77,14 @@ private:
   wxDocChildFrame* CreateChildFrame(wxDocument *doc, wxView *view);
 #endif
 
+  void Draw();
+  void DrawSurface();
+  void CreateDisplayList();
+  void InitMaterials();
+  void InitGL();
+
+  Graph3dFileCanvas *CreateCanvas (wxFrame* parent);
+
   wxWindow* getFrameForChild()
 #if CTSIM_MDI
   { return theApp->getMainFrame(); }
@@ -137,8 +135,10 @@ private:
   Graph3dFileView* m_pView;
 
 public:
-   Graph3dFileCanvas (Graph3dFileView* view, wxWindow *parent, const wxPoint& pos = wxDefaultPosition,
-      const wxSize& size = wxDefaultSize, long style = 0);
+   Graph3dFileCanvas (Graph3dFileView* view, wxWindow *parent,
+                      int* attribList,
+                      const wxPoint& pos = wxDefaultPosition,
+                      const wxSize& size = wxDefaultSize, long style = 0);
    virtual ~Graph3dFileCanvas();
 
    void OnPaint(wxPaintEvent& event);
