@@ -7,9 +7,7 @@
 **   Date Started:  February 2001
 **
 **  This is part of the CTSim program
-**  Copyright (C) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (C) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -56,12 +54,12 @@ private:
   const double m_dCenterDetectorLength;
   const double m_dViewRatio;
   const double m_dScanRatio;
-  const std::string m_strLabel;
+  const wxString m_strLabel;
 
 public:
   ProjectorSupervisorThread(PhantomFileView* pProjView, int iNDet, int iNView, int iOffsetView,
    const char* pszGeometry, int iNSample, double dRotation, double dFocalLength, double dCenterDetectorLength,
-   double dViewRatio, double dScanRatio, const char* const pszLabel);
+   double dViewRatio, double dScanRatio, wxChar const* strLabel);
 
   virtual wxThread::ExitCode Entry();
 
@@ -88,13 +86,13 @@ private:
   const double m_dCenterDetectorLength;
   const double m_dViewRatio;
   const double m_dScanRatio;
-  const char* const m_pszLabel;
+  const wxString m_strLabel;
 
 
 public:
    ProjectorSupervisor (SupervisorThread* pThread, PhantomFileView* pProjView, int iNDet, int iNView,  int iOffsetView,
    const char* pszGeometry, int iNSample, double dRotation, double dFocalLength, double dCenterDetectorLength,
-   double dViewRatio, double dScanRatio, const char* const pszLabel);
+   double dViewRatio, double dScanRatio, wxChar const* pszLabel);
 
    virtual BackgroundWorkerThread* createWorker (int iThread, int iStartUnit, int iNumUnits);
 
