@@ -7,9 +7,7 @@
 **   Date Started:  February 2001
 **
 **  This is part of the CTSim program
-**  Copyright (C) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (C) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -57,7 +55,7 @@
 /////////////////////////////////////////////////////////////////////
 
 RasterizerSupervisorThread::RasterizerSupervisorThread (PhantomFileView* pProjView, int iNX, int iNY,
-                                                        int iNSample, double dViewRatio, const char* const pszLabel)
+                                                        int iNSample, double dViewRatio, wxChar const* pszLabel)
                                                         :   SupervisorThread(), m_pPhantomView(pProjView), m_iNX(iNX), m_iNY(iNY), m_iNSample(iNSample), m_dViewRatio(dViewRatio), m_strLabel(pszLabel)
 {
 }
@@ -65,7 +63,7 @@ RasterizerSupervisorThread::RasterizerSupervisorThread (PhantomFileView* pProjVi
 wxThread::ExitCode
 RasterizerSupervisorThread::Entry()
 {
-  RasterizerSupervisor rasterSupervisor (this, m_pPhantomView, m_iNX, m_iNY, m_iNSample, m_dViewRatio, m_strLabel.c_str());
+  RasterizerSupervisor rasterSupervisor (this, m_pPhantomView, m_iNX, m_iNY, m_iNSample, m_dViewRatio, m_strLabel);
 
   rasterSupervisor.start();
 
@@ -75,9 +73,9 @@ RasterizerSupervisorThread::Entry()
 
   if (rasterSupervisor.fail())
   {
-    wxString msg ("Error starting Rasterizer supervisor: ");
-    msg += rasterSupervisor.getFailMessage().c_str();
-    msg += "\n";
+    wxString msg (_T("Error starting Rasterizer supervisor: "));
+    msg += rasterSupervisor.getFailMessage();
+    msg += _T("\n");
     wxCommandEvent eventLog (wxEVT_COMMAND_MENU_SELECTED, MAINMENU_LOG_EVENT );
     eventLog.SetString( msg );
     wxPostEvent( theApp->getMainFrame(), eventLog ); // send log event
@@ -103,10 +101,10 @@ RasterizerSupervisorThread::OnExit()
 /////////////////////////////////////////////////////////////////////
 
 RasterizerSupervisor::RasterizerSupervisor (SupervisorThread* pThread, PhantomFileView* pPhantomView, int iNX, int iNY,
-                                            int iNSample, double dViewRatio, const char* const pszLabel)
-                                            : BackgroundSupervisor (pThread, pPhantomView->GetFrame(), pPhantomView->GetDocument(), "Rasterizing", iNX),
+                                            int iNSample, double dViewRatio, wxChar const* pszLabel)
+  : BackgroundSupervisor (pThread, pPhantomView->GetFrame(), pPhantomView->GetDocument(), _T("Rasterizing"), iNX),
                                             m_pPhantomView(pPhantomView), m_pPhantomDoc(pPhantomView->GetDocument()),
-                                            m_iNX(iNX), m_iNY(iNY), m_iNSample(iNSample), m_dViewRatio(dViewRatio), m_pszLabel(pszLabel)
+                                            m_iNX(iNX), m_iNY(iNY), m_iNSample(iNSample), m_dViewRatio(dViewRatio), m_strLabel(pszLabel)
 {
   m_vecpChildImageFiles.reserve (getNumWorkers());
   for (int iThread = 0; iThread < getNumWorkers(); iThread++) {
@@ -137,11 +135,11 @@ RasterizerSupervisor::onDone()
   wxCriticalSectionLocker critsect (doneSection);
 
   ImageFile* pImageFile = getImageFile();
-  pImageFile->labelAdd (m_pszLabel, getTimerEnd());
+  pImageFile->labelAdd (m_strLabel.mb_str(wxConvUTF8), getTimerEnd());
 
   wxCommandEvent eventLog (wxEVT_COMMAND_MENU_SELECTED, MAINMENU_LOG_EVENT );
-  wxString msg (m_pszLabel);
-  msg += "\n";
+  wxString msg (m_strLabel);
+  msg += _T("\n");
   eventLog.SetString( msg );
   wxPostEvent( theApp->getMainFrame(), eventLog ); // send log event
 
@@ -199,7 +197,7 @@ RasterizerWorker::Entry ()
 #ifdef DEBUG
       if (theApp->getVerboseLogging()) {
         wxString msg;
-        msg.Printf("Worker thread: Received destroy message at work unit #%d\n", iUnit);
+        msg.Printf(_T("Worker thread: Received destroy message at work unit #%d\n"), iUnit);
         wxCommandEvent event( wxEVT_COMMAND_MENU_SELECTED, MAINMENU_LOG_EVENT );
         event.SetString( msg );
         wxPostEvent( theApp->getMainFrame(), event );
