@@ -7,9 +7,7 @@
 **   Date Started:  February 2001
 **
 **  This is part of the CTSim program
-**  Copyright (C) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (C) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -50,10 +48,10 @@ private:
   const int m_iNY;
   const int m_iNSample;
   const double m_dViewRatio;
-  const std::string m_strLabel;
+  const wxString m_strLabel;
 
 public:
-  RasterizerSupervisorThread(PhantomFileView* pProjView, int iNX, int iNY, int iNSample, double dViewRatio, const char* const pszLabel);
+  RasterizerSupervisorThread(PhantomFileView* pProjView, int iNX, int iNY, int iNSample, double dViewRatio, wxChar const* strLabel);
 
   virtual wxThread::ExitCode Entry();
   virtual void OnExit();
@@ -72,12 +70,12 @@ private:
   const int m_iNY;
   const int m_iNSample;
   const double m_dViewRatio;
-  const char* const m_pszLabel;
+  const wxString m_strLabel;
 
 
 public:
    RasterizerSupervisor (SupervisorThread* pThread, PhantomFileView* pProjView, int iNX, int iNY,
-   int iNSample, double dViewRatio, const char* const pszLabel);
+   int iNSample, double dViewRatio, wxChar const* pszLabel);
 
    virtual BackgroundWorkerThread* createWorker (int iThread, int iStartUnit, int iNumUnits);
 
