@@ -7,9 +7,7 @@
 **   Date Started:  February 2001
 **
 **  This is part of the CTSim program
-**  Copyright (C) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (C) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -59,14 +57,14 @@ private:
   const std::string m_strInterpName;
   const int m_iInterpParam;
   const std::string m_strBackprojectName;
-  const std::string m_strLabel;
+  const wxString m_strLabel;
   ReconstructionROI m_reconROI;
   const bool m_bRebinToParallel;
 
 public:
   ReconstructorSupervisorThread(ProjectionFileView* pProjView, int iNX, int iNY, const char* pszFilterName,
    double dFilterParam, const char* pszFilterMethod, int iZeropad, const char* pszFilterGenerationName,
-   const char* pszInterpName, int iInterpParam, const char* pszBackprojectName, const char* const pszLabel,
+   const char* pszInterpName, int iInterpParam, const char* pszBackprojectName, wxChar const* pszLabel,
    ReconstructionROI* pROI, bool bRebinToParallel);
 
   virtual wxThread::ExitCode Entry();
@@ -95,14 +93,14 @@ private:
   const char* const m_pszInterpName;
   const int m_iInterpParam;
   const char* const m_pszBackprojectName;
-  const char* const m_pszLabel;
+  const wxString m_strLabel;
   ReconstructionROI* m_pReconROI;
 
 public:
    ReconstructorSupervisor (SupervisorThread* pMyThread, Projections* pProj, ProjectionFileView* pProjView,
    int iNX, int iNY, const char* pszFilterName, double dFilterParam, const char* pszFilterMethod, int iZeropad,
    const char* pszFilterGenerationName, const char* pszInterpName, int iInterpParam,
-   const char* pszBackprojectName, const char* const pszLabel, ReconstructionROI* pReconROI);
+   const char* pszBackprojectName, wxChar const* pszLabel, ReconstructionROI* pReconROI);
 
    virtual BackgroundWorkerThread* createWorker (int iThread, int iStartUnit, int iNumUnits);
 
