@@ -7,9 +7,7 @@
 **   Date Started:  February 2001
 **
 **  This is part of the CTSim program
-**  Copyright (C) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (C) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -83,7 +81,7 @@ CTSimTipProvider::GetTip()
   size_t iThisTip = m_iCurrentTip;
   ++m_iCurrentTip;
 
-  return wxString (s_aszTips[iThisTip]);
+  return wxString (wxConvUTF8.cMB2WX(s_aszTips[iThisTip]));
 }
 
 size_t
