@@ -125,7 +125,9 @@ ifexport_main (int argc, char *const argv[])
   int opt_center = O_CENTER_MEDIAN;
   int opt_format = O_FORMAT_PGM;
   int opt_labels = 0;
-
+  UNUSED(opt_verbose);
+  UNUSED(opt_debug);
+  
   while (1)
     {
       int c = getopt_long (argc, argv, "", my_options, NULL);
